Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'build_files/cmake/platform/platform_apple.cmake')
-rw-r--r--build_files/cmake/platform/platform_apple.cmake6
1 files changed, 2 insertions, 4 deletions
diff --git a/build_files/cmake/platform/platform_apple.cmake b/build_files/cmake/platform/platform_apple.cmake
index 620a078f412..f5f8c209d9d 100644
--- a/build_files/cmake/platform/platform_apple.cmake
+++ b/build_files/cmake/platform/platform_apple.cmake
@@ -222,12 +222,10 @@ if(WITH_OPENCOLLADA)
-lMathMLSolver
-lGeneratedSaxParser
-lbuffer -lftoa -lUTF
- ${OPENCOLLADA_LIBPATH}/libxml2.a
)
# PCRE is bundled with openCollada
# set(PCRE ${LIBDIR}/pcre)
# set(PCRE_LIBPATH ${PCRE}/lib)
set(PCRE_LIBRARIES pcre)
+ set(XML2_LIBRARIES xml2)
endif()
if(WITH_SDL)
@@ -222,12 +222,10 @@ if(WITH_OPENCOLLADA)
)
- # PCRE is bundled with openCollada
- # set(PCRE ${LIBDIR}/pcre)
- # set(PCRE_LIBPATH ${PCRE}/lib)
+ # PCRE and XML2 are bundled with OpenCollada.
set(PCRE_LIBRARIES pcre)